<?php
/**
 * Register meta boxes
 *
 * @since 1.0
 *
 * @param array $meta_boxes
 *
 * @return array
 */
function ourea_register_meta_boxes( $meta_boxes ) {

	// Start with an underscore to hide fields from custom fields list
	$prefix = '_cmb_';

	// Post format
	$meta_boxes[] = array(
		'id'       => 'format_detail',
		'title'    => __( 'Format Details', 'ourea' ),
		'pages'    => array( 'post' ),
		'context'  => 'normal',
		'priority' => 'high',
		'autosave' => true,
		'fields'   => array(
			array(
				'name'             => __( 'Image', 'ourea' ),
				'id'               => $prefix . 'image',
				'type'             => 'image_advanced',
				'class'            => 'image',
				'max_file_uploads' => 1,
			),
			array(
				'name'  => __( 'Gallery', 'ourea' ),
				'id'    => $prefix . 'images',
				'type'  => 'image_advanced',
				'class' => 'gallery',
			),
			array(
				'name'  => __( 'Quote', 'ourea' ),
				'id'    => $prefix . 'quote',
				'type'  => 'textarea',
				'cols'  => 20,
				'rows'  => 2,
				'class' => 'quote',
			),
			array(
				'name'  => __( 'Author', 'ourea' ),
				'id'    => $prefix . 'quote_author',
				'type'  => 'text',
				'class' => 'quote',
			),			
			array(
				'name'  => __( 'Audio', 'ourea' ),
				'id'    => $prefix . 'link_audio',
				'type'  => 'textarea',
				'cols'  => 20,
				'rows'  => 2,
				'class' => 'audio',
				'desc' => 'Ex: https://w.soundcloud.com/player/?url=https%3A//api.soundcloud.com/tracks/139083759',
			),
			array(
				'name'  => __( 'Video', 'ourea' ),
				'id'    => $prefix . 'link_video',
				'type'  => 'textarea',
				'cols'  => 20,
				'rows'  => 2,
				'class' => 'video',
				'desc' => 'Example: <b>http://www.youtube.com/embed/0ecv0bT9DEo</b> or <b>http://player.vimeo.com/video/47355798</b>',
			),	
		),
	);	
	
    $meta_boxes[] = array(
        'id'         => 'page_setting',
        'title'      => 'Page Setting',
        'pages'      => array('page'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
        	array(
                'name' => 'Upload Background Image Top',
                'desc' => 'Recommend: 1920x1280',
                'id' => $prefix . 'bg_page',
                'type'             => 'image_advanced',				
				'max_file_uploads' => 1,
            ),     
            array(
                'name' => 'Page Title',
                'desc' => 'Set Page Title, use for template blog, template default, template full width.',
                'id'   => $prefix . 'page_title',
                'type'    => 'text',
            ), 
            array(
                'name' => 'Page SubTitle',
                'desc' => 'Set Page SubTitle, use for template blog, template default, template full width.',
                'id'   => $prefix . 'page_subtitle',
                'type'  => 'textarea',
				'cols'  => 20,
				'rows'  => 2,
            ), 
            array(
				'name'             => __( 'Background Image Action', 'ourea' ),
				'desc' 			   => 'Recommend: 1920x1280',
				'id'               => $prefix . 'bg_action',
				'type'             => 'image_advanced',				
				'max_file_uploads' => 1,
			),
            array(
                'name' => 'Action',
                'desc' => 'Set Page SubTitle, use for template blog, template default, template full width.',
                'id'   => $prefix . 'blog_action',
                'type'  => 'textarea',
				'cols'  => 20,
				'rows'  => 2,
            ),  
            array(
                'name' => 'Action Author',
                'desc' => 'Set Page Title, use for template blog, template default, template full width.',
                'id'   => $prefix . 'blog_action_author',
                'type'    => 'text',
            ),                
        )
    );
	// Add other metaboxes as needed	
    $meta_boxes[] = array(
        'id'         => 'portfolio_setting',
        'title'      => 'Portfolio Setting',
        'pages'      => array('portfolio', 'slide'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(                       
            array(
                'name' => 'SubTitle',
                'desc' => '',
                'id'   => $prefix . 'folio_stitle',
                'type'  => 'textarea',
				'cols'  => 20,
				'rows'  => 2,
            ),                 
        )
    );
	// Add other metaboxes as needed

	return $meta_boxes;
}
add_filter( 'rwmb_meta_boxes', 'ourea_register_meta_boxes' );

/**
 * Enqueue scripts for admin
 *
 * @since  1.0
 */
function ourea_admin_enqueue_scripts( $hook ) {
	// Detect to load un-minify scripts when WP_DEBUG is enable
	$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

	if ( in_array( $hook, array( 'post.php', 'post-new.php' ) ) ) {
		wp_enqueue_script( 'ourea-backend-js', get_template_directory_uri()."/js/admin.js", array( 'jquery' ), '1.0', true );
	}
}
add_action( 'admin_enqueue_scripts', 'ourea_admin_enqueue_scripts' );
