<?php

    /**
     * For full documentation, please visit: http://docs.reduxframework.com/
     * For a more extensive sample-config file, you may look at:
     * https://github.com/reduxframework/redux-framework/blob/master/sample/sample-config.php
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }

    // This is your option name where all the Redux data is stored.
    $opt_name = "theme_option";

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        'opt_name' => 'theme_option',
        'use_cdn' => TRUE,
        'display_name'     => $theme->get('Name'),
        'display_version'  => $theme->get('Version'),
        'page_title' => 'Ourea Options',
        'update_notice' => FALSE,
        'admin_bar' => TRUE,
        'menu_type' => 'menu',
        'menu_title' => 'Ourea Options',
        'allow_sub_menu' => TRUE,
        'page_parent_post_type' => 'your_post_type',
        'customizer' => false,
        'dev_mode'   => false,
        'default_mark' => '*',
        'hints' => array(
            'icon_position' => 'right',
            'icon_color' => 'lightgray',
            'icon_size' => 'normal',
            'tip_style' => array(
                'color' => 'light',
            ),
            'tip_position' => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect' => array(
                'show' => array(
                    'duration' => '500',
                    'event' => 'mouseover',
                ),
                'hide' => array(
                    'duration' => '500',
                    'event' => 'mouseleave unfocus',
                ),
            ),
        ),
        'output' => TRUE,
        'output_tag' => TRUE,
        'settings_api' => TRUE,
        'cdn_check_time' => '1440',
        'compiler' => TRUE,
        'page_permissions' => 'manage_options',
        'save_defaults' => TRUE,
        'show_import_export' => TRUE,
        'database' => 'options',
        'transient_time' => '3600',
        'network_sites' => TRUE,
    );

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */

    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => esc_html__( 'Theme Information 1', 'ourea' ),
            'content' => esc_html__( 'This is the tab content, HTML is allowed.', 'ourea' )
        ),
        array(
            'id'      => 'redux-help-tab-2',
            'title'   => esc_html__( 'Theme Information 2', 'ourea' ),
            'content' => esc_html__( 'This is the tab content, HTML is allowed.', 'ourea' )
        )
    );
    Redux::setHelpTab( $opt_name, $tabs );

    // Set the help sidebar
    $content = esc_html__( 'This is the sidebar content, HTML is allowed.', 'ourea' );
    Redux::setHelpSidebar( $opt_name, $content );


    /*
     * <--- END HELP TABS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

    // ACTUAL DECLARATION OF SECTIONS          
    Redux::setSection( $opt_name, array(
        'icon' => 'el-icon-cogs',
        'title' => __('General Settings', 'ourea'),
        'fields' => array(  
            array(
                'id'   =>'divider_1',
                'desc' => __('Preload Settings', 'ourea'),
                'type' => 'divide'
            ),                                  
            array(
                'id' => 'show_pre',
                'type' => 'select',
                'title' => __('Show Preload?', 'ourea'),
                'subtitle' => __('Option Show Preload', 'ourea'),
                'desc' => __('', 'ourea'),
                'options'  => array(
                    'yes' => 'Yes',
                    'no'  => 'No',
                ),
                'default' => 'yes',
            ), 
            array(
                'id' => 'background_preload',
                'type' => 'color',
                'title' => __('Preload Background Color', 'ourea'),
                'subtitle' => __('Pick a background color for the preload (default: #ffffff).', 'ourea'),
                'default' => '#ffffff',
                'validate' => 'color',
            ),
            array(
                'id' => 'text_preload',
                'type' => 'text',
                'title' => __('Preload Text ', 'ourea'),
                'subtitle' => __('Text for the preload (default: OUREA).', 'ourea'),
                'default' => 'OUREA',                        
            ),
            array(
                'id' => 'color_preload',
                'type' => 'color',
                'title' => __('Preload Text Color', 'ourea'),
                'subtitle' => __('Pick a Text color for the preload (default: #16a085).', 'ourea'),
                'default' => '#16a085',
                'validate' => 'color',
            ),
            array(
                'id' => 'gmap_api',
                'type' => 'text',
                'title' => esc_html__('Google Map API Key', 'ourea'),
                'subtitle' => esc_html__('Add your Google map api key', 'ourea'),
                'desc' => esc_html__('Create your Gmap API key here: https://developers.google.com/maps/documentation/javascript/', 'ourea'),
                'default' => 'AIzaSyDZJDaC3vVJjxIi2QHgdctp3Acq8UR2Fgk'
            ), 
        )
    ) );
    
    Redux::setSection( $opt_name, array(
        'icon' => ' el-icon-picture',
        'title' => __('Logo & Favicon Settings', 'ourea'),
        'fields' => array(
            array(
                'id' => 'favicon',
                'type' => 'media',
                'url' => true,
                'title' => __('Custom Favicon', 'ourea'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => __('Upload your Favicon.', 'ourea'),
                'subtitle' => __('', 'ourea'),
                'default' => array('url' => get_template_directory_uri().'/images/favicon.png'),
            ),                    
            array(
                'id' => 'logo',
                'type' => 'media',
                'url' => true,
                'title' => __('Logo', 'ourea'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => __('Upload your logo.', 'ourea'),
                'subtitle' => __('Recommended size: Height: auto and Width: 120px', 'ourea'),
                'default' => array('url' => get_template_directory_uri().'/images/logo.png'),
            ), 
            array(
                'id'   =>'divider_1',
                'desc' => esc_html__('Please fixed Width & Height & Top for Logo display on static devices.', 'ourea'),
                'type' => 'divide'
            ), 
            array(
                'id' => 'widthlg',
                'type' => 'text',
                'title' => esc_html__('Fix Width Logo static, Default: 134', 'ourea'),
                'subtitle' => esc_html__('Input Width Logo, remember enter number.', 'ourea'),
                'default' => '134'
            ),  
            array(
                'id' => 'heightlg',
                'type' => 'text',
                'title' => esc_html__('Fix Height Logo static, Default: 25', 'ourea'),
                'subtitle' => esc_html__('Input Height Logo, remember enter number.', 'ourea'),
                'default' => '25'
            ),         
            array(
                'id' => 'toplg',
                'type' => 'text',
                'title' => esc_html__('Fix margin top Logo static, Default: 50', 'ourea'),
                'subtitle' => esc_html__('Input top Logo, remember enter number.', 'ourea'),
                'default' => '50'
            ),          
            array(
                'id'   =>'divider_2',
                'desc' => esc_html__('Please fixed Width & Height & Margin Top for Logo when scroll down page.', 'ourea'),
                'type' => 'divide'
            ),
            array(
                'id' => 'widthlg_scroll',
                'type' => 'text',
                'title' => esc_html__('Fix Width Logo scroll, Default: 86', 'ourea'),
                'subtitle' => esc_html__('Input Width Logo, remember enter number.', 'ourea'),
                'default' => '86'
            ),  
            array(
                'id' => 'heightlg_scroll',
                'type' => 'text',
                'title' => esc_html__('Fix Height Logo scroll, Default: 16', 'ourea'),
                'subtitle' => esc_html__('Input Height Logo, remember enter number.', 'ourea'),
                'default' => '16'
            ),         
            array(
                'id' => 'toplg_scroll',
                'type' => 'text',
                'title' => esc_html__('Fix margin top Logo scroll, Default: 32', 'ourea'),
                'subtitle' => esc_html__('Input top Logo, remember enter number.', 'ourea'),
                'default' => '32'
            ),     
            array(
                'id'   =>'divider_3',
                'desc' => esc_html__('Please fixed Width & Height & Top for Logo display on mobile devices.', 'ourea'),
                'type' => 'divide'
            ),
            array(
                'id' => 'widthlg_mobie',
                'type' => 'text',
                'title' => esc_html__('Fix Width Logo display on mobile devices, Default: 80', 'ourea'),
                'subtitle' => esc_html__('Input Width Logo, remember enter number.', 'ourea'),
                'default' => '80'
            ),  
            array(
                'id' => 'heightlg_mobie',
                'type' => 'text',
                'title' => esc_html__('Fix Height Logo display on mobile devices, Default: 15', 'ourea'),
                'subtitle' => esc_html__('Input Height Logo, remember enter number.', 'ourea'),
                'default' => '15'
            ),         
            array(
                'id' => 'toplg_mobie',
                'type' => 'text',
                'title' => esc_html__('Fix margin top Logo display on mobile devices, Default: 30', 'ourea'),
                'subtitle' => esc_html__('Input top Logo, remember enter number.', 'ourea'),
                'default' => '30'
            ),                                                                             
            array(
                'id' => 'apple_icon',
                'type' => 'media',
                'url' => true,
                'title' => __('Apple Touch Icon 57x57', 'ourea'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => __('Upload your Apple touch icon 57x57.', 'ourea'),
                'subtitle' => __('', 'ourea'),
                'default' => array('url' => get_template_directory_uri().'/images/apple-touch-icon.png'),
            ),                  
            array(
                'id' => 'apple_icon_72',
                'type' => 'media',
                'url' => true,
                'title' => __('Apple Touch Icon 72x72', 'ourea'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => __('Upload your Apple touch icon 72x72.', 'ourea'),
                'subtitle' => __('', 'ourea'),
                'default' => array('url' => get_template_directory_uri().'/images/apple-touch-icon-72x72.png'),
            ),
            array(
                'id' => 'apple_icon_114',
                'type' => 'media',
                'url' => true,
                'title' => __('Apple Touch Icon 114x114', 'ourea'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => __('Upload your Apple touch icon 114x114.', 'ourea'),
                'subtitle' => __('', 'ourea'),
                'default' => array('url' => get_template_directory_uri().'/images/apple-touch-icon-114x114.png'),
            ),                  
        )
    ) );
    Redux::setSection( $opt_name, array(
        'icon' => 'el-icon-qrcode',
        'title' => __('Header Settings', 'ourea'),
        'fields' => array(                  
            array(
                'id' => 'header_layout',
                'type' => 'image_select',
                'title' => __('Header Layout', 'ourea'),
                'subtitle' => __('Select Your Header layout', 'ourea'),
                'desc' => '',
                'options' => array(
                    'header1' => array(
                        'alt'   => 'Hlayout 1',
                        'img'   => get_template_directory_uri().'/images/hlayout11.png'
                    ),
                    'header2' => array(
                        'alt'   => 'Hlayout 2',
                        'img'   => get_template_directory_uri().'/images/hlayout22.png'
                    ),                        
                ), 
                'default' => 'header1'
            ),
            array(
                'id' => 'menu_text',
                'type' => 'text',
                'title' => __('Button Menu Title', 'ourea'),
                'subtitle' => __('Input Button Menu Title', 'ourea'),
                'desc' => __('Use For Header Layout First', 'ourea'),
                'default' => ''
            ),
            
        )
    ) );
    
    Redux::setSection( $opt_name, array(
        'icon' => 'el-icon-hourglass',
        'title' => __('Coming Soon Settings', 'ourea'),
        'fields' => array(
           array(
                'id' => 'cms_logo',
                'type' => 'media',
                'url' => true,
                'title' => __('Logo', 'ourea'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => __('Upload your logo.', 'ourea'),
                'subtitle' => __('Recommended size: Height: auto and Width: 120px', 'ourea'),
                'default' => array('url' => get_template_directory_uri().'/images/logo-green.png'),
            ),                 
           array(
                'id'          => 'cmsoon_date',
                'type'        => 'date',
                'title'       => __('Date Option', 'ourea'), 
                'subtitle'    => __('No validation can be done on this field type', 'ourea'),
                'desc'        => __('This is the description field, again good for additional info.', 'ourea'),
                'placeholder' => 'Click to enter a date',
                'default' => '12/23/2015'
            ),
            array(
                'id' => 'cs_bg',
                'type' => 'media',
                'title' => __('Background Image', 'ourea'),
                'subtitle' => __('', 'ourea'),
                'desc' => __('', 'ourea'),
                'default' => array('url' => get_template_directory_uri().'/images/32.jpg')
            ),      
            array(
                'id' => 'cs_title',
                'type' => 'text',
                'title' => __('Coming Soon Title', 'ourea'),
                'subtitle' => __('', 'ourea'),
                'desc' => __('', 'ourea'),
                'default' => 'WE ARE ALMOST READY'
            ),                              
            array(
                'id' => 'cs_stitle',
                'type' => 'text',
                'title' => __('Coming Soon Subtitle', 'ourea'),
                'subtitle' => __('', 'ourea'),
                'desc' => __('', 'ourea'),
                'default' => '',
            ),                                     
        )    
    ) );
    
    Redux::setSection( $opt_name, array(
        'icon' => 'el-icon-blogger',
        'title' => __('Blog Settings', 'ourea'),
        'fields' => array(  
            array(
                'id' => 'background-parallax-blog',
                'type' => 'media',
                'url' => true,
                'title' => __('Custom Background Parallax Blog', 'ourea'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => __('Upload your Background Parallax Blog.', 'ourea'),
                'subtitle' => __('', 'ourea'),
                'default' => array('url' => get_template_directory_uri().'/images/parallax-blog.jpg'),
            ),
            array(
                'id' => 'blog_title',
                'type' => 'text',
                'title' => __('Blog Title', 'ourea'),
                'subtitle' => __('Input Blog Title', 'ourea'),
                'desc' => __('', 'ourea'),
                'default' => 'latest news'
            ),
            array(
                'id' => 'blog_subtitle',
                'type' => 'text',
                'title' => __('Blog Sub Title', 'ourea'),
                'subtitle' => __('Input Blog Sub Title', 'ourea'),
                'desc' => __('', 'ourea'),
                'default' => 'show your talents'
            ),      
            array(
                'id' => 'background-parallax-3',
                'type' => 'media',
                'url' => true,
                'title' => __('Custom Background Parallax Action', 'ourea'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => __('Upload your Background Parallax Action.', 'ourea'),
                'subtitle' => __('', 'ourea'),
                'default' => array('url' => get_template_directory_uri().'/images/3.jpg'),
            ),
            array(
                'id' => 'blog_action',
                'type' => 'editor',
                'title' => __('Blog Action Wrap', 'ourea'),
                'subtitle' => __('Input Blog Action Wrap', 'ourea'),
                'desc' => __('', 'ourea'),
                'default' => 'Put your blog out into the world and hope that your talent will speak for itself.'
            ), 
            array(
                'id' => 'blog_action_author',
                'type' => 'text',
                'title' => __('Blog Action Wrap Author', 'ourea'),
                'subtitle' => __('Input Blog Action Wrap Author', 'ourea'),
                'desc' => __('', 'ourea'),
                'default' => 'Diablo Cody'
            ),    
            array(
                'id' => 'blog_excerpt',
                'type' => 'text',
                'title' => __('Excerpt Leght', 'ourea'),
                'subtitle' => __('Input Excerpt Leght', 'ourea'),
                'desc' => __('', 'ourea'),
                'default' => '30'
            ),                  
            array(
                'id' => 'read_more',
                'type' => 'text',
                'title' => __('Button Text For Post', 'ourea'),
                'subtitle' => __('Input Button Text', 'ourea'),
                'desc' => __('', 'ourea'),
                'default' => 'Read more'
            ),                                                    
         )
    ) );
    
    
    Redux::setSection( $opt_name, array(
        'icon' => 'el-icon-graph',
        'title' => __('404 Settings', 'ourea'),
        'fields' => array(
             array(
                'id' => '404_title',
                'type' => 'text',
                'title' => __('404 Title', 'ourea'),
                'subtitle' => __('Input 404 Title', 'ourea'),
                'desc' => __('', 'ourea'),
                'default' => '404'
            ),                              
             array(
                'id' => '404_content',
                'type' => 'editor',
                'title' => __('404 Content', 'ourea'),
                'subtitle' => __('Enter 404 Content', 'ourea'),
                'desc' => __('', 'ourea'),
                'default' => 'The page you are looking for no longer exists. Perhaps you can return back to the sites homepage see you can find what you are looking for.'
            ),      
            array(
                'id' => 'back_404',
                'type' => 'text',
                'title' => __('Button Back Home', 'ourea'),                        
                'desc' => __('Text Button Go To Home.', 'ourea'),
                'subtitle' => __('', 'ourea'),
                'default' => 'Back To Home',
            ),                  
         )
    ) );
    
    Redux::setSection( $opt_name, array(

        'icon' => 'el-icon-group',

        'title' => __('Social Settings', 'ourea'),

        'fields' => array(
            array(

                'id' => 'facebook',

                'type' => 'text',

                'title' => __('Facebook Url', 'ourea'),

                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.

                'default' => 'https://www.facebook.com/',

            ),

            array(

                'id' => 'google',

                'type' => 'text',

                'title' => __('Google+ Url', 'ourea'),

                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.

                'default' => 'https://plus.google.com',

            ),

            array(

                'id' => 'twitter',

                'type' => 'text',

                'title' => __('Twitter Url', 'ourea'),

                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.

                'default' => 'https://twitter.com/',

            ),

            array(

                'id' => 'youtube',

                'type' => 'text',

                'title' => __('Youtube Url', 'ourea'),

                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.

                'default' => 'https://youtube.com/',

            ),

            array(

                'id' => 'linkedin',

                'type' => 'text',

                'title' => __('Linkedin Url', 'ourea'),

                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.

                'default' => 'https://www.linkedin.com/',

            ),

            array(

                'id' => 'dribbble',

                'type' => 'text',

                'title' => __('Dribbble Url', 'ourea'),

                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.

                'default' => 'https://www.dribbble.com/',

            ),

            array(

                'id' => 'pinterest',

                'type' => 'text',

                'title' => __('Pinterest Url', 'ourea'),

                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.

                'default' => 'https://www.pinterest.com/',

            ),                    

            array(

                'id' => 'instagram',

                'type' => 'text',

                'title' => __('Instagram Url', 'ourea'),

                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.

                'default' => 'https://www.instagram.com/',

            ),

            array(

                'id' => 'skype',

                'type' => 'text',

                'title' => __('Skype Url', 'ourea'),

                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.

                'default' => ''

            ),         

            array(

                'id' => 'github',

                'type' => 'text',

                'title' => __('Github Url', 'ourea'),

                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.

                'default' => ''

            ),  
            array(

                'id' => 'vimeo',

                'type' => 'text',

                'title' => __('Vimeo Url', 'ourea'),

                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.

                'default' => ''

            ),  
            array(

                'id' => 'tumblr',

                'type' => 'text',

                'title' => __('tumblr Url', 'ourea'),

                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.

                'default' => ''

            ),  
            array(

                'id' => 'soundcloud',

                'type' => 'text',

                'title' => __('soundcloud Url', 'ourea'),

                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.

                'default' => ''

            ),  
            array(

                'id' => 'behance',

                'type' => 'text',

                'title' => __('behance Url', 'ourea'),

                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.

                'default' => ''

            ),  
            array(

                'id' => 'lastfm',

                'type' => 'text',

                'title' => __('lastfm Url', 'ourea'),

                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.

                'default' => ''

            ),                     

        )

    ) );

    Redux::setSection( $opt_name, array(
        'icon' => ' el-icon-credit-card',
        'title' => __('Footer Settings', 'ourea'),
        'fields' => array(                                          
            array(
                'id' => 'flogo',
                'type' => 'media',
                'url' => true,
                'title' => __('Logo Footer', 'ourea'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => __('Upload your logo footer.', 'ourea'),
                'subtitle' => __('Recommended size: Height: auto and Width: 90px', 'ourea'),
                'default' => array('url' => get_template_directory_uri().'/images/logo-green.png'),
            ),  
            array(
                'id' => 'background-parallax-footer',
                'type' => 'media',
                'url' => true,
                'title' => __('Custom Background Parallax Footer', 'ourea'),
                'compiler' => 'true',
                //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                'desc' => __('Upload your Background Parallax Footer.', 'ourea'),
                'subtitle' => __('', 'ourea'),
                'default' => array('url' => get_template_directory_uri().'/images/footer-pattern.png'),
            ),  
            array(
                'id' => 'footer_text_link',
                'type' => 'text',
                'title' => __('Footer Text Link', 'ourea'),
                'subtitle' => __('Copyright Text', 'ourea'),
                'default' => '© OUREA 2015.',
            ),
            array(
                'id' => 'footer_link',
                'type' => 'text',
                'title' => __('Footer Link', 'ourea'),
                'subtitle' => __('Link Text', 'ourea'),
                'default' => 'http://themeforest.net/user/OceanThemes/portfolio?ref=OceanThemes',
            ),          
            array(
                'id' => 'footer_text',
                'type' => 'editor',
                'title' => __('Footer Text', 'ourea'),
                'subtitle' => __('Copyright Text', 'ourea'),
                'default' => 'Made by OceanThemes',
            ),                      
        )
    ) );
    Redux::setSection( $opt_name, array(
        'icon' => 'el-icon-website',
        'title' => __('Styling Options', 'ourea'),
        'fields' => array(
            
            array(
                'id' => 'main_color',
                'type' => 'color',
                'title' => __('Theme Main Color', 'ourea'),
                'subtitle' => __('Pick the main color for the theme (default: #16a085).', 'ourea'),
                'default' => '#16a085',
                'validate' => 'color',
            ),  
                        
            array(
                'id' => 'body-font2',
                'type' => 'typography',
                'output' => array('body'),
                'title' => __('Body Font', 'ourea'),
                'subtitle' => __('Specify the body font properties.', 'ourea'),
                'google' => true,
                'default' => array(
                    'color' => '',
                    'font-size' => '',
                    'line-height' => '',
                    'font-family' => '',
                    'font-weight' => ''
                ),
            ),
             array(
                'id' => 'custom-css',
                'type' => 'ace_editor',
                'title' => __('CSS Code', 'ourea'),
                'subtitle' => __('Paste your CSS code here.', 'ourea'),
                'mode' => 'css',
                'theme' => 'monokai',
                'desc' => 'Possible modes can be found at <a href="http://ace.c9.io" target="_blank">http://ace.c9.io/</a>.',
                'default' => "#header{\nmargin: 0 auto;\n}"
            ),
        )
    ) );

    /*
     * <--- END SECTIONS
     */
