<?php
/**
 * Redux Theme functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package ourea
 */

if ( ! class_exists( 'ReduxFramewrk' ) ) {
    require_once( get_template_directory() . '/framework/sample-config.php' );
	function removeDemoModeLink() { // Be sure to rename this function to something more unique
		if ( class_exists('ReduxFrameworkPlugin') ) {
			remove_filter( 'plugin_row_meta', array( ReduxFrameworkPlugin::get_instance(), 'plugin_metalinks'), null, 2 );
		}
		if ( class_exists('ReduxFrameworkPlugin') ) {
			remove_action('admin_notices', array( ReduxFrameworkPlugin::get_instance(), 'admin_notices' ) );    
		}
	}
	add_action('init', 'removeDemoModeLink');
}

//Theme Set up:
function ourea_theme_setup() {

	/*

	 * Make theme available for translation.

	 * Translations can be filed in the /languages/ directory.

	 * If you're building a theme based on cubic, use a find and replace

	 * to change 'cubic' to the name of your theme in all the template files

	 */

	load_theme_textdomain( 'ourea', get_template_directory() . '/languages' );

	/** Set Content width **/
	if ( ! isset( $content_width ) ) {
		$content_width = 900;
	}

    /*
     * This theme uses a custom image size for featured images, displayed on
     * "standard" posts and pages.
     */
	add_theme_support( 'custom-header' ); 
	add_theme_support( 'custom-background' );
	add_theme_support( "title-tag" );
    add_theme_support( 'post-thumbnails' );
    // Adds RSS feed links to <head> for posts and comments.
    add_theme_support( 'automatic-feed-links' );
    // Switches default core markup for search form, comment form, and comments
    // to output valid HTML5.
    add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list' ) );
    //Post formats
    add_theme_support( 'post-formats', array(
        'audio',  'gallery', 'image', 'video', 'quote'
    ) );
    // This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary'   => __('Primary Menu', 'ourea'),
		'onepage'   => __('One Page Menu', 'ourea'),
	) );
}
add_action( 'after_setup_theme', 'ourea_theme_setup' );

function ourea_load_custom_wp_admin_style() {
        wp_register_style( 'custom_wp_admin_css', get_template_directory_uri() . '/framework/admin/admin-style.css', false, '1.0.0' );
        wp_enqueue_style( 'custom_wp_admin_css' );
}
add_action( 'admin_enqueue_scripts', 'ourea_load_custom_wp_admin_style' );

/**
 * Register custom fonts.
 */
if ( ! function_exists( 'ourea_fonts_url' ) ) :
/**
 * Register Google fonts for Ourea.
 *
 * Create your own ourea_fonts_url() function to override in a child theme.
 *
 * @since Ourea 1.0
 *
 * @return string Google fonts URL for the theme.
 */
function ourea_fonts_url() {
	$fonts_url = '';
	$font_families     = array();
	$subsets   = 'latin,latin-ext';

	/* translators: If there are characters in your language that are not supported by Lato, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Lato font: on or off', 'ourea' ) ) {
		$font_families[] = 'Lato:100,300,400,700,900,100italic,300italic,400italic,700italic,900italic';
	}

	/* translators: If there are characters in your language that are not supported by Inconsolata, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Inconsolata font: on or off', 'ourea' ) ) {
		$font_families[] = 'Inconsolata:400,700';
	}

	if ( $font_families ) {
		$fonts_url = add_query_arg( array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( $subsets ),
		), 'https://fonts.googleapis.com/css' );
	}
	return esc_url_raw( $fonts_url );
}
endif;

function ourea_theme_scripts_styles() {
	global $theme_option;
	$protocol = is_ssl() ? 'https' : 'http';  
	$gmap_api = (!empty($theme_option['gmap_api']) ? $theme_option['gmap_api'] : 'AIzaSyDZJDaC3vVJjxIi2QHgdctp3Acq8UR2Fgk');

	// Add custom fonts, used in the main stylesheet.
	wp_enqueue_style( 'ourea-fonts', ourea_fonts_url(), array(), null );

	wp_enqueue_style( 'ourea-base', get_template_directory_uri().'/css/base.css');
	wp_enqueue_style( 'ourea-skeleton', get_template_directory_uri().'/css/skeleton.css');	
	wp_enqueue_style( 'ourea-font-awesome', get_template_directory_uri().'/css/font-awesome/css/font-awesome.min.css');
	wp_enqueue_style( 'ourea-font-ionicons', get_template_directory_uri().'/css/ionicons.css');	
	wp_enqueue_style( 'ourea-retina', get_template_directory_uri().'/css/retina.css');
	wp_enqueue_style( 'ourea-carousel', get_template_directory_uri().'/css/owl.carousel.css');
	wp_enqueue_style( 'ourea-transitions', get_template_directory_uri().'/css/owl.transitions.css');	
	wp_enqueue_style( 'ourea-theme-style', get_stylesheet_uri(), array(), '2017-07-09' );
	wp_enqueue_style( 'color-style', get_template_directory_uri().'/framework/color.php');	

	wp_enqueue_script("modernizr", get_template_directory_uri()."/js/modernizr.js",array(),false,false);
	wp_enqueue_script( "ourea-maps-js", "$protocol://maps.googleapis.com/maps/api/js?key=$gmap_api",array('jquery'),false,false);
	if($theme_option['show_pre'] != 'no') {
		wp_enqueue_script("royal_preloader", get_template_directory_uri()."/js/royal_preloader.min.js",array(),false,false);
	}
	wp_enqueue_script("ourea-cbpAnimatedHeader", get_template_directory_uri()."/js/cbpAnimatedHeader.min.js",array(),false,true);
	wp_enqueue_script("ourea-menu-classic", get_template_directory_uri()."/js/menu-classic.js",array(),false,true);
	wp_enqueue_script("ourea-malihu-js", get_template_directory_uri()."/js/jquery.malihu.PageScroll2id.js",array(),false,true);
	wp_enqueue_script("ourea-classie-js", get_template_directory_uri()."/js/classie.js",array(),false,true);			
	wp_enqueue_script("ourea-retina-1.1.0", get_template_directory_uri()."/js/retina-1.1.0.min.js",array(),false,true);
	wp_enqueue_script("ourea-jquery.easing", get_template_directory_uri()."/js/jquery.easing.js",array(),false,true);
	wp_enqueue_script("ourea-menu", get_template_directory_uri()."/js/menu.js",array(),false,true);
	wp_enqueue_script("ourea-jquery.fs.tipper", get_template_directory_uri()."/js/jquery.fs.tipper.min.js",array(),false,true);
	wp_enqueue_script("ourea-owlcarousel", get_template_directory_uri()."/js/owl.carousel.min.js",array(),false,false);
	wp_enqueue_script("ourea-parallax", get_template_directory_uri()."/js/jquery.parallax-1.1.3.js",array(),false,true);
	wp_enqueue_script("ourea-chaffle", get_template_directory_uri()."/js/jquery.chaffle.min.js",array(),false,true);
	wp_enqueue_script("ourea-portfolio-ajax", get_template_directory_uri()."/js/portfolio-ajax.js",array(),false,true);
	wp_enqueue_script("ourea-imagesloaded", get_template_directory_uri()."/js/imagesloaded.pkgd.min.js",array(),false,true);
	wp_enqueue_script("ourea-masonry", get_template_directory_uri()."/js/mas-project.js",array(),false,true);
	wp_enqueue_script("ourea-isotope-theme", get_template_directory_uri()."/js/isotope.js",array(),false,true);
	wp_enqueue_script("ourea-counterup", get_template_directory_uri()."/js/jquery.counterup.min.js",array(),false,true);
	wp_enqueue_script("ourea-waypoints-theme", get_template_directory_uri()."/js/waypoints.min.js",array(),false,true);
	wp_enqueue_script("ourea-scrollReveal", get_template_directory_uri()."/js/scrollReveal.js",array(),false,true);	
	wp_enqueue_script("ourea-fitvids", get_template_directory_uri()."/js/jquery.fitvids.js",array(),false,true);	
		
	wp_enqueue_script("ourea-template-js", get_template_directory_uri()."/js/template.js",array(),false,true);

}
add_action( 'wp_enqueue_scripts', 'ourea_theme_scripts_styles');

if(!function_exists('ourea_custom_frontend_style')){
	function ourea_custom_frontend_style(){
	global $theme_option;
	echo '<style type="text/css">'.$theme_option['custom-css'].'</style>';
}
}
add_action('wp_head', 'ourea_custom_frontend_style');


if(!function_exists('ourea_custom_frontend_scripts')){
	function ourea_custom_frontend_scripts(){
	global $theme_option;		
	if($theme_option['show_pre'] != 'no') {	
	$textpre = (!empty($theme_option['text_preload']) ? $theme_option['text_preload'] : 'OUREA');
	$bgcolor = (!empty($theme_option['background_preload']) ? $theme_option['background_preload'] : '#ffffff');
	?>
		<script type="text/javascript">
			(function($) { "use strict";
	            Royal_Preloader.config({
	                mode:           'text', // 'number', "text" or "logo"
	                text:           '<?php echo esc_attr($textpre); ?>',
	                timeout:        0,
	                showInfo:       true,
	                opacity:        1,
	                background:     ['<?php echo esc_attr($bgcolor); ?>']
	            });
			})(jQuery);	
		</script>
	<?php
	}		
   }
}
add_action('wp_footer', 'ourea_custom_frontend_scripts');

/**
 * Adds custom classes to the array of body classes.
 *
 * @since Ourea 1.5
 *
 * @param array $classes Classes for the body element.
 * @return array (Maybe) filtered body classes.
 */
function ourea_body_classes( $classes ) {
	global $theme_option;

	// Adds a class of hfeed to non-singular pages.
	if($theme_option['show_pre'] != 'no') {
		$classes[] = 'royal_preloader';
	}

	return $classes;
}
add_filter( 'body_class', 'ourea_body_classes' );

// Widget Sidebar
function ourea_widgets_init() {
	register_sidebar( array(
        'name'          => __( 'Primary Sidebar', 'ourea' ),
        'id'            => 'sidebar-1',        
		'description'   => __( 'Appears in the sidebar section of the site.', 'ourea' ),        
		'before_widget' => '<div id="%1$s" class="widget %2$s">',        
		'after_widget'  => '</div>',        
		'before_title'  => '<h6>',        
		'after_title'   => '</h6>'
    ) );
}
add_action( 'widgets_init', 'ourea_widgets_init' );

//function tag widgets
function ourea_tag_cloud_widget($args) {
	$args['number'] = 0; //adding a 0 will display all tags
	$args['largest'] = 10; //largest tag
	$args['smallest'] = 10; //smallest tag
	$args['unit'] = 'px'; //tag font unit
	$args['format'] = 'list'; //ul with a class of wp-tag-cloud
	$args['exclude'] = ''; //exclude tags by ID
	return $args;
}
add_filter( 'widget_tag_cloud_args', 'ourea_tag_cloud_widget' );

// ourea custom excerpt lenght
function ourea_excerpt() {
  global $theme_option;
  if(isset($theme_option['blog_excerpt'])){
    $limit = $theme_option['blog_excerpt'];
  }else{
    $limit = 30;
  }
  $excerpt = explode(' ', get_the_excerpt(), $limit);
  if (count($excerpt)>=$limit) {
    array_pop($excerpt);
    $excerpt = implode(" ",$excerpt).'...';
  } else {
    $excerpt = implode(" ",$excerpt);
  }
  $excerpt = preg_replace('`[[^]]*]`','',$excerpt);
  return $excerpt;
}

// Excerpt Section Blog Post
function ourea_blog_excerpt($limit) {
  $excerpt = explode(' ', get_the_excerpt(), $limit);
  if (count($excerpt)>=$limit) {
    array_pop($excerpt);
    $excerpt = implode(" ",$excerpt).'...';
  } else {
    $excerpt = implode(" ",$excerpt);
  }
  $excerpt = preg_replace('`[[^]]*]`','',$excerpt);
  return $excerpt;
}

//pagination
function ourea_pagination($prev = 'PREV', $next = 'NEXT', $pages='') {
    global $wp_query, $wp_rewrite;
    $wp_query->query_vars['paged'] > 1 ? $current = $wp_query->query_vars['paged'] : $current = 1;
    if($pages==''){
        global $wp_query;
         $pages = $wp_query->max_num_pages;
         if(!$pages)
         {
             $pages = 1;
         }
    }
    $pagination = array(
		'base' 			=> str_replace( 999999999, '%#%', get_pagenum_link( 999999999 ) ),
		'format' 		=> '',
		'current' 		=> max( 1, get_query_var('paged') ),
		'total' 		=> $pages,
		'prev_text' => $prev,
        'next_text' => $next,		
        'type'			=> 'list',
		'end_size'		=> 3,
		'mid_size'		=> 3
);
    $return =  paginate_links( $pagination );
	echo str_replace( "<ul class='page-numbers'>", '<ul class="cd-pagination animated-buttons custom-icons">', $return );
}

function ourea_search_form( $form ) {
    $form = '<form role="search" method="get" id="searchform" class="search_form" action="' . home_url( '/' ) . '" >  
    	<input type="text" value="' . get_search_query() . '" name="s" id="s" placeholder="'.__('type to search and hit enter', 'ourea').'" />
    </form>';
    return $form;
}
add_filter( 'get_search_form', 'ourea_search_form' );
//Custom comment List:

// Comment Form
function ourea_theme_comment($comment, $args, $depth) {
   $GLOBALS['comment'] = $comment; ?>
   <div class="post-content-comment grey-section">
		<?php echo get_avatar($comment,$size='100',$default='http://0.gravatar.com/avatar/ad516503a11cd5ca435acc9bb6523536?s=70' ); ?>
		<h6><?php printf(__('%s','ourea'), get_comment_author_link()) ?></h6>
		<?php if ($comment->comment_approved == '0'){ ?>
			 <p><em><?php _e('Your comment is awaiting moderation.','ourea') ?></em></p>
		<?php }else{ ?>
        	<?php comment_text() ?>
		<?php } ?>
		<div class="reply"><?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?></div> 
		<div class="clearfix"></div>	
	</div> 
<?php
}

//Code Visual Compurso.
function ourea_custom_css_classes_for_vc_row_and_vc_column($class_string, $tag) {
    if($tag=='vc_row' || $tag=='vc_row_inner') {
        $class_string = str_replace('vc_row-fluid', '', $class_string);
    }
    if($tag=='vc_column' || $tag=='vc_column_inner') {
    	$class_string = preg_replace('/vc_col-sm-1/', 'one columns', $class_string);
		$class_string = preg_replace('/vc_col-sm-2/', 'two columns', $class_string);		
		$class_string = preg_replace('/vc_col-sm-3/', 'three columns', $class_string);
		$class_string = preg_replace('/vc_col-sm-4/', 'four columns', $class_string);		
		$class_string = preg_replace('/vc_col-sm-5/', 'five columns ', $class_string);
		$class_string = preg_replace('/vc_col-sm-6/', 'six columns', $class_string);
		$class_string = preg_replace('/vc_col-sm-7/', 'seven columns', $class_string);
		$class_string = preg_replace('/vc_col-sm-8/', 'eight columns', $class_string);
		$class_string = preg_replace('/vc_col-sm-9/', 'nine columns', $class_string);
		$class_string = preg_replace('/vc_col-sm-10/', 'ten columns', $class_string);
		$class_string = preg_replace('/vc_col-sm-11/', 'eleven columns', $class_string);	
		$class_string = preg_replace('/vc_col-sm-12/', 'twelve columns', $class_string);	
    }
    return $class_string;
}
// Filter to Replace default css class for vc_row shortcode and vc_column
add_filter('vc_shortcodes_css_class', 'ourea_custom_css_classes_for_vc_row_and_vc_column', 10, 2); 

// Add new Param in Row
if(function_exists('vc_add_param')){

vc_add_param('vc_row',array(
                              "type" => "textfield",
                              "heading" => __('Section Title', 'ourea'),
                              "param_name" => "ses_title",
                              "value" => "",
                              "description" => __("Title of Section, Leave a blank do not show frontend.", 'ourea'),   
    ));	
vc_add_param('vc_row',array(
                              "type" => "dropdown",
                              "heading" => __('Fullwidth', 'ourea'),
                              "param_name" => "full_width",
                              "value" => array(   
                                                __('No', 'ourea') => 'no',  
                                                __('Yes', 'ourea') => 'yes',                                                                                
                                              ),
                              "description" => __("Select Fullwidth or not, Default: No fullwidth", 'ourea'),      
                            ) 
    );	

	vc_remove_param( "vc_column", "offset" );
	vc_remove_param( "vc_row", "parallax" );
    vc_remove_param( "vc_row", "parallax_image" );    
    vc_remove_param( "vc_row", "full_height" );
    vc_remove_param( "vc_row", "video_bg" );
    vc_remove_param( "vc_row", "video_bg_parallax" );
    vc_remove_param( "vc_row", "content_placement" );
    vc_remove_param( "vc_row", "video_bg_url" );
    vc_remove_param( "vc_row", "parallax_speed_bg" );
    vc_remove_param( "vc_row", "parallax_speed_video" );
    vc_remove_param( "vc_row", "columns_placement" );
    vc_remove_param( "vc_row", "equal_height" );
    vc_remove_param( "vc_row", "gap" );
	
}

/**
 * Include the TGM_Plugin_Activation class.
 */
require get_template_directory() . '/framework/class-tgm-plugin-activation.php';
add_action( 'tgmpa_register', 'ourea_theme_register_required_plugins' );
/**
 * Register the required plugins for this theme.
 *
 * In this example, we register two plugins - one included with the TGMPA library
 * and one from the .org repo.
 *
 * The variable passed to tgmpa_register_plugins() should be an array of plugin
 * arrays.
 *
 * This function is hooked into tgmpa_init, which is fired within the
 * TGM_Plugin_Activation class constructor.
 */
function ourea_theme_register_required_plugins() {

	/*
	 * Array of plugin arrays. Required keys are name and slug.
	 * If the source is NOT from the .org repo, then source is also required.
	 */
	$plugins = array(
		// This is an example of how to include a plugin from the WordPress Plugin Repository.
		array(
            'name'      => 'Contact Form 7',
            'slug'      => 'contact-form-7',
            'required'  => false,
        ),
		array(
            'name'               => 'Meta Box',
            'slug'               => 'meta-box',
            'required'           => true,
            'force_activation'   => false,
            'force_deactivation' => false,
        ),
        array(
            'name'      => 'Redux Framework',
            'slug'      => 'redux-framework',
            'required'           => true,
            'force_activation'   => false,
            'force_deactivation' => false,
        ), 
		array(            
			'name'               => 'WPBakery Visual Composer', // The plugin name.
            'slug'               => 'js_composer', // The plugin slug (typically the folder name).
            'source'             => 'http://ivang-design.com/wordpress-demos/plugins-required/js_composer.zip', // The plugin source.
            'required'           => true, // If false, the plugin is only 'recommended' instead of required.
            'version'            => '5.4.2', // E.g. 1.0.0. If set, the active plugin must be this version or higher. If the plugin version is higher than the plugin version installed, the user will be notified to update the plugin.
            'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
            'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
            'external_url'       => '', // If set, overrides default API URL and points to an external URL.
            'is_callable'        => '', // If set, this callable will be be checked for availability to determine if a plugin is active.
        ),          
		array(            
			'name'               => 'OT Portfolio', // The plugin name.
            'slug'               => 'ot_portfolio', // The plugin slug (typically the folder name).
            'source'             => 'http://ivang-design.com/wordpress-demos/plugins-required/ourea/ot_portfolio.zip', // The plugin source.
            'required'           => false, // If false, the plugin is only 'recommended' instead of required.
        ), 
        array(            
			'name'               => 'OT Testimonial', // The plugin name.
            'slug'               => 'ot_testimonial', // The plugin slug (typically the folder name).
            'source'             => 'http://ivang-design.com/wordpress-demos/plugins-required/ourea/ot_testimonial.zip', // The plugin source.
            'required'           => false, // If false, the plugin is only 'recommended' instead of required.
        ),       
        array(            
			'name'               => 'OT Visual Composer', // The plugin name.
            'slug'               => 'ot_composer', // The plugin slug (typically the folder name).
            'source'             => 'http://ivang-design.com/wordpress-demos/plugins-required/ourea/ot_composer.zip', // The plugin source.
            'required'           => false, // If false, the plugin is only 'recommended' instead of required.
        ),    
		array(            
            'name'               => 'OT One Click Import Demo Content', // The plugin name.
            'slug'               => 'ot-themes-one-click-import', // The plugin slug (typically the folder name).
            'source'             => 'http://ivang-design.com/wordpress-demos/plugins-required/ourea/ot-themes-one-click-import.zip', // The plugin source.
            'required'           => false, // If false, the plugin is only 'recommended' instead of required.
        ), 
	);

	/*
	 * Array of configuration settings. Amend each line as needed.
	 * If you want the default strings to be available under your own theme domain,
	 * leave the strings uncommented.
	 * Some of the strings are wrapped in a sprintf(), so see the comments at the
	 * end of each line for what each argument will be.
	 */
	$config = array(
		'id'           => 'tgmpa',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to pre-packaged plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'parent_slug'  => 'themes.php',            // Parent menu slug.
		'capability'   => 'edit_theme_options',    // Capability needed to view plugin install page, should be a capability associated with the parent menu used.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
		'strings'      => array(
			'page_title'                      => __( 'Install Required Plugins', 'ourea' ),
			'menu_title'                      => __( 'Install Plugins', 'ourea' ),
			'installing'                      => __( 'Installing Plugin: %s', 'ourea' ), // %s = plugin name.
			'oops'                            => __( 'Something went wrong with the plugin API.', 'ourea' ),
			'notice_can_install_required'     => _n_noop(
				'This theme requires the following plugin: %1$s.',
				'This theme requires the following plugins: %1$s.',
				'ourea'
			), // %1$s = plugin name(s).
			'notice_can_install_recommended'  => _n_noop(
				'This theme recommends the following plugin: %1$s.',
				'This theme recommends the following plugins: %1$s.',
				'ourea'
			), // %1$s = plugin name(s).
			'notice_cannot_install'           => _n_noop(
				'Sorry, but you do not have the correct permissions to install the %s plugin.',
				'Sorry, but you do not have the correct permissions to install the %s plugins.',
				'ourea'
			), // %1$s = plugin name(s).
			'notice_can_activate_required'    => _n_noop(
				'The following required plugin is currently inactive: %1$s.',
				'The following required plugins are currently inactive: %1$s.',
				'ourea'
			), // %1$s = plugin name(s).
			'notice_can_activate_recommended' => _n_noop(
				'The following recommended plugin is currently inactive: %1$s.',
				'The following recommended plugins are currently inactive: %1$s.',
				'ourea'
			), // %1$s = plugin name(s).
			'notice_cannot_activate'          => _n_noop(
				'Sorry, but you do not have the correct permissions to activate the %s plugin.',
				'Sorry, but you do not have the correct permissions to activate the %s plugins.',
				'ourea'
			), // %1$s = plugin name(s).
			'notice_ask_to_update'            => _n_noop(
				'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.',
				'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.',
				'ourea'
			), // %1$s = plugin name(s).
			'notice_cannot_update'            => _n_noop(
				'Sorry, but you do not have the correct permissions to update the %s plugin.',
				'Sorry, but you do not have the correct permissions to update the %s plugins.',
				'ourea'
			), // %1$s = plugin name(s).
			'install_link'                    => _n_noop(
				'Begin installing plugin',
				'Begin installing plugins',
				'ourea'
			),
			'activate_link'                   => _n_noop(
				'Begin activating plugin',
				'Begin activating plugins',
				'ourea'
			),
			'return'                          => __( 'Return to Required Plugins Installer', 'ourea' ),
			'plugin_activated'                => __( 'Plugin activated successfully.', 'ourea' ),
			'complete'                        => __( 'All plugins installed and activated successfully. %s', 'ourea' ), // %s = dashboard link.
			'contact_admin'                   => __( 'Please contact the administrator of this site for help.', 'tgmpa' ),

			'nag_type'                        => 'updated', // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
		)
	);
	tgmpa( $plugins, $config );
}

//Custom fields:
require get_template_directory() . '/framework/meta-boxes.php';

?>